# 🎲 Bookshelf Random

This datapack provides a variety of random functions, including different distributions and noise patterns.

> “Creativity is the ability to introduce order into the randomness of nature.”
>
> -- Eric Hoffer

For more details and usage examples, check out the Bookshelf [documentation](https://docs.mcbookshelf.dev/en/latest/modules/random.html).


## 📖 About Bookshelf

This module is part of the [Bookshelf Library](https://docs.mcbookshelf.dev/en/latest/index.html), a modular library datapack designed to simplify complex systems in Minecraft. Explore the full range of modules and discover how Bookshelf can simplify your Minecraft creations!
